Module: RunLoop::Core

Defined in:
lib/run_loop/core.rb

Constant Summary collapse

START_DELIMITER =
"OUTPUT_JSON:\n"
END_DELIMITER =
"\nEND_OUTPUT"
SCRIPTS_PATH =
File.expand_path(File.join(File.dirname(__FILE__), '..', '..', 'scripts'))
SCRIPTS =
{
    :dismiss => 'run_dismiss_location.js',
    :run_loop_fast_uia => 'run_loop_fast_uia.js',
    :run_loop_shared_element => 'run_loop_shared_element.js',
    :run_loop_host => 'run_loop_host.js',
    :run_loop_basic => 'run_loop_basic.js'
}
READ_SCRIPT_PATH =
File.join(SCRIPTS_PATH, 'read-cmd.sh')
TIMEOUT_SCRIPT_PATH =
File.join(SCRIPTS_PATH, 'timeout3')

Class Method Summary collapse

Class Method Details

.above_or_eql_version?(target_version, xcode_version) ⇒ Boolean

Deprecated.

since 1.0.0

still used extensively in calabash-ios launcher

Returns:

  • (Boolean)


57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/run_loop/core.rb', line 57

def self.above_or_eql_version?(target_version, xcode_version)
  if target_version.is_a?(RunLoop::Version)
    target = target_version
  else
    target = RunLoop::Version.new(target_version)
  end

  if xcode_version.is_a?(RunLoop::Version)
    xcode = xcode_version
  else
    xcode = RunLoop::Version.new(xcode_version)
  end
  target >= xcode
end

.automation_template(xctools, candidate = ) ⇒ Object



557
558
559
560
561
562
# File 'lib/run_loop/core.rb', line 557

def self.automation_template(xctools, candidate = ENV['TRACE_TEMPLATE'])
  unless candidate && File.exist?(candidate)
    candidate = default_tracetemplate xctools
  end
  candidate
end

.create_uia_pipe(repl_path) ⇒ Object



414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/run_loop/core.rb', line 414

def self.create_uia_pipe(repl_path)
  begin
    Timeout::timeout(5, TimeoutError) do
      loop do
        begin
          FileUtils.rm_f(repl_path)
          return repl_path if system(%Q[mkfifo "#{repl_path}"])
        rescue Errno::EINTR => e
          #retry
          sleep(0.1)
        end
      end
    end
  rescue TimeoutError => _
    raise TimeoutError, 'Unable to create pipe (mkfifo failed)'
  end
end

.default_simulator(xcode_tools = RunLoop::XCTools.new) ⇒ Object

Returns the a default simulator to target. This default needs to be one that installed by default in the current Xcode version.

For historical reasons, the most recent non-64b SDK should be used.

Parameters:

  • xcode_tools (RunLoop::XCTools) (defaults to: RunLoop::XCTools.new)

    Used to detect the current xcode version.



348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/run_loop/core.rb', line 348

def self.default_simulator(xcode_tools=RunLoop::XCTools.new)
  if xcode_tools.xcode_version_gte_63?
    'iPhone 5s (8.3 Simulator)'
  elsif xcode_tools.xcode_version_gte_62?
    'iPhone 5s (8.2 Simulator)'
  elsif xcode_tools.xcode_version_gte_61?
    'iPhone 5s (8.1 Simulator)'
  elsif xcode_tools.xcode_version_gte_6?
    'iPhone 5s (8.0 Simulator)'
  else
    'iPhone Retina (4-inch) - Simulator - iOS 7.1'
  end
end

.default_tracetemplate(xctools = RunLoop::XCTools.new) ⇒ Object



564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/run_loop/core.rb', line 564

def self.default_tracetemplate(xctools=RunLoop::XCTools.new)
  templates = xctools.instruments :templates

  # xcrun instruments -s templates
  # Xcode >= 6 will return known, Apple defined tracetemplates as names
  #  e.g.  Automation, Zombies, Allocations
  #
  # Xcode < 6 will return known, Apple defined tracetemplates as paths.
  #
  # Xcode 6 Beta versions also return paths, but revert to 'normal'
  # behavior when GM is released.
  res = templates.select { |name| name == 'Automation' }.first
  return res if res

  res = templates.select do |path|
    path =~ /\/Automation.tracetemplate/ and path =~ /Xcode/
  end.first.tr("\"", '').strip
  return res if res

  msgs = ['Expected instruments to report an Automation tracetemplate.',
          'Please report this as bug:  https://github.com/calabash/run_loop/issues',
          "In the bug report, include the output of:\n",
          '$ xcrun xcodebuild -version',
          "$ xcrun instruments -s templates\n"]
  raise msgs.join("\n")
end

.detect_connected_deviceObject



79
80
81
82
83
84
85
86
87
88
# File 'lib/run_loop/core.rb', line 79

def self.detect_connected_device
  begin
    Timeout::timeout(1, TimeoutError) do
      return `#{File.join(scripts_path, 'udidetect')}`.chomp
    end
  rescue TimeoutError => _
    `killall udidetect &> /dev/null`
  end
  nil
end

.dylib_path_from_options(options) ⇒ String?

Extracts the value of :inject_dylib from options Hash.

Parameters:

Returns:

  • (String, nil)

    If the options contains :inject_dylibs and it is a path to a dylib that exists, return the path. Otherwise return nil or raise an error.

Raises:

  • (RuntimeError)

    If :inject_dylib points to a path that does not exist.

  • (ArgumentError)

    If :inject_dylib is not a String.



328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/run_loop/core.rb', line 328

def self.dylib_path_from_options(options)
  inject_dylib = options.fetch(:inject_dylib, nil)
  return nil if inject_dylib.nil?
  unless inject_dylib.is_a? String
    raise ArgumentError, "Expected :inject_dylib to be a path to a dylib, but found '#{inject_dylib}'"
  end
  dylib_path = File.expand_path(inject_dylib)
  unless File.exist?(dylib_path)
    raise "Cannot load dylib.  The file '#{dylib_path}' does not exist."
  end
  dylib_path
end

.ensure_instruments_not_running!Object

Deprecated.

1.0.5



606
607
608
# File 'lib/run_loop/core.rb', line 606

def self.ensure_instruments_not_running!
  RunLoop::Instruments.new.kill_instruments
end

.escape_host_command(cmd) ⇒ Object



471
472
473
474
# File 'lib/run_loop/core.rb', line 471

def self.escape_host_command(cmd)
  backquote = "\\"
  cmd.gsub(backquote,backquote*4)
end

.expect_compatible_simulator_architecture(launch_options, sim_control) ⇒ Object

Note:

This method is implemented for CoreSimulator environments only; for Xcode < 6.0 this method does nothing.

Raise an error if the application binary is not compatible with the target simulator.

Parameters:

  • launch_options (Hash)

    These options need to contain the app bundle path and a udid that corresponds to a simulator name or simulator udid. In practical terms: call this after merging the original launch options with those options that are discovered.

  • sim_control (RunLoop::SimControl)

    A simulator control object.

Raises:

  • (RuntimeError)

    Raises an error if the launch_options[:udid] cannot be used to find a simulator.

  • (RunLoop::IncompatibleArchitecture)

    Raises an error if the application binary is not compatible with the target simulator.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/run_loop/core.rb', line 106

def self.expect_compatible_simulator_architecture(launch_options, sim_control)
  if sim_control.xcode_version_gte_6?
    sim_identifier = launch_options[:udid]
    simulator = sim_control.simulators.find do |simulator|
      [simulator.instruments_identifier(sim_control.xctools),
       simulator.udid].include?(sim_identifier)
    end

    if simulator.nil?
      raise "Could not find simulator with identifier '#{sim_identifier}'"
    end

    lipo = RunLoop::Lipo.new(launch_options[:bundle_dir_or_bundle_id])
    lipo.expect_compatible_arch(simulator)
    if ENV['DEBUG'] == '1'
      puts "Simulator instruction set '#{simulator.instruction_set}' is compatible with #{lipo.info}"
    end
    true
  else
    if ENV['DEBUG'] == '1'
      puts "Xcode #{sim_control.xctools.xcode_version} detected; skipping simulator architecture check."
    end
    false
  end
end

.instruments_pidsObject

Deprecated.

1.0.5



615
616
617
# File 'lib/run_loop/core.rb', line 615

def self.instruments_pids
  RunLoop::Instruments.new.instruments_pids
end

.instruments_running?Boolean

Returns:

  • (Boolean)


610
611
612
# File 'lib/run_loop/core.rb', line 610

def self.instruments_running?
  RunLoop::Instruments.new.instruments_running?
end

.jruby?Boolean

Returns:

  • (Boolean)


432
433
434
# File 'lib/run_loop/core.rb', line 432

def self.jruby?
  RUBY_PLATFORM == 'java'
end

.log(message) ⇒ Object



591
592
593
594
595
596
# File 'lib/run_loop/core.rb', line 591

def self.log(message)
  if ENV['DEBUG']=='1'
    puts "#{Time.now } #{message}"
    $stdout.flush
  end
end

.log_header(message) ⇒ Object



598
599
600
601
602
603
# File 'lib/run_loop/core.rb', line 598

def self.log_header(message)
  if ENV['DEBUG']=='1'
    puts "\n\e[#{35}m### #{message} ###\e[0m"
    $stdout.flush
  end
end

.log_run_loop_options(options, xctools) ⇒ Object



38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/run_loop/core.rb', line 38

def self.log_run_loop_options(options, xctools)
  return unless ENV['DEBUG'] == '1'
  # Ignore :sim_control b/c it is a ruby object; printing is not useful.
  ignored_keys = [:sim_control]
  options_to_log = {}
  options.each_pair do |key, value|
    next if ignored_keys.include?(key)
    options_to_log[key] = value
  end
  # Objects that override '==' cannot be printed by awesome_print
  # https://github.com/michaeldv/awesome_print/issues/154
  # RunLoop::Version overrides '=='
  options_to_log[:xcode] = xctools.xcode_version.to_s
  options_to_log[:xcode_path] = xctools.xcode_developer_dir
  ap(options_to_log, {:sort_keys => true})
end

.pids_for_run_loop(run_loop, &block) ⇒ Object

Deprecated.

1.0.5



553
554
555
# File 'lib/run_loop/core.rb', line 553

def self.pids_for_run_loop(run_loop, &block)
  RunLoop::Instruments.new.instruments_pids(&block)
end

.read_response(run_loop, expected_index, empty_file_timeout = 10, search_for_property = 'index') ⇒ Object



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
# File 'lib/run_loop/core.rb', line 476

def self.read_response(run_loop, expected_index, empty_file_timeout=10, search_for_property='index')
  log_file = run_loop[:log_file]
  initial_offset = run_loop[:initial_offset] || 0
  offset = initial_offset

  result = nil
  loop do
    unless File.exist?(log_file) && File.size?(log_file)
      sleep(0.2)
      next
    end


    size = File.size(log_file)

    output = File.read(log_file, size-offset, offset)

    if /AXError: Could not auto-register for pid status change/.match(output)
      if /kAXErrorServerNotFound/.match(output)
        $stderr.puts "\n\n****** Accessibility is not enabled on device/simulator, please enable it *** \n\n"
        $stderr.flush
      end
      raise TimeoutError.new('AXError: Could not auto-register for pid status change')
    end
    if /Automation Instrument ran into an exception/.match(output)
      raise TimeoutError.new('Exception while running script')
    end
    index_if_found = output.index(START_DELIMITER)
    if ENV['DEBUG_READ']=='1'
      puts output.gsub('*', '')
      puts "Size #{size}"
      puts "offset #{offset}"
      puts "index_of #{START_DELIMITER}: #{index_if_found}"
    end

    if index_if_found

      offset = offset + index_if_found
      rest = output[index_if_found+START_DELIMITER.size..output.length]
      index_of_json = rest.index("}#{END_DELIMITER}")

      if index_of_json.nil?
        #Wait for rest of json
        sleep(0.1)
        next
      end

      json = rest[0..index_of_json]


      if ENV['DEBUG_READ']=='1'
        puts "Index #{index_if_found}, Size: #{size} Offset #{offset}"

        puts ("parse #{json}")
      end

      offset = offset + json.size
      parsed_result = JSON.parse(json)
      if ENV['DEBUG_READ']=='1'
        p parsed_result
      end
      json_index_if_present = parsed_result[search_for_property]
      if json_index_if_present && json_index_if_present == expected_index
        result = parsed_result
        break
      end
    else
      sleep(0.1)
    end
  end

  run_loop[:initial_offset] = offset
  RunLoop::HostCache.default.write(run_loop)
  result
end

.run_with_options(options) ⇒ Object



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/run_loop/core.rb', line 132

def self.run_with_options(options)
  before = Time.now

  sim_control ||= options[:sim_control] || RunLoop::SimControl.new
  xctools ||= options[:xctools] || sim_control.xctools

  instruments = RunLoop::Instruments.new
  instruments.kill_instruments

  device_target = options[:udid] || options[:device_target] || detect_connected_device || 'simulator'
  if device_target && device_target.to_s.downcase == 'device'
    device_target = detect_connected_device
  end

  log_file = options[:log_path]
  timeout = options[:timeout] || 30

  results_dir = options[:results_dir] || Dir.mktmpdir('run_loop')
  results_dir_trace = File.join(results_dir, 'trace')
  FileUtils.mkdir_p(results_dir_trace)

  dependencies = options[:dependencies] || []
  dependencies << File.join(scripts_path, 'calabash_script_uia.js')
  dependencies.each do |dep|
    FileUtils.cp(dep, results_dir)
  end

  script = File.join(results_dir, '_run_loop.js')

  code = File.read(options[:script])
  code = code.gsub(/\$PATH/, results_dir)
  code = code.gsub(/\$READ_SCRIPT_PATH/, READ_SCRIPT_PATH)
  code = code.gsub(/\$TIMEOUT_SCRIPT_PATH/, TIMEOUT_SCRIPT_PATH)
  code = code.gsub(/\$MODE/, 'FLUSH') unless options[:no_flush]

  repl_path = File.join(results_dir, 'repl-cmd.pipe')
  FileUtils.rm_f(repl_path)

  uia_strategy = options[:uia_strategy]
  if uia_strategy == :host
    create_uia_pipe(repl_path)
    RunLoop::HostCache.default.clear
  end

  cal_script = File.join(SCRIPTS_PATH, 'calabash_script_uia.js')
  File.open(script, 'w') do |file|
    if include_calabash_script?(options)
      file.puts IO.read(cal_script)
    end
    file.puts code
  end

  # Compute udid and bundle_dir / bundle_id from options and target depending on Xcode version
  udid, bundle_dir_or_bundle_id = udid_and_bundle_for_launcher(device_target, options, xctools)

  args = options.fetch(:args, [])

  log_file ||= File.join(results_dir, 'run_loop.out')

  after = Time.now
  if ENV['DEBUG'] == '1'
    puts "Preparation took #{after-before} seconds"
  end

  discovered_options =
        {
              :udid => udid,
              :results_dir_trace => results_dir_trace,
              :bundle_dir_or_bundle_id => bundle_dir_or_bundle_id,
              :results_dir => results_dir,
              :script => script,
              :log_file => log_file,
              :args => args
        }
  merged_options = options.merge(discovered_options)

  if self.simulator_target?(merged_options, sim_control)
    # @todo only enable accessibility on the targeted simulator
    sim_control.enable_accessibility_on_sims({:verbose => false})
    self.expect_compatible_simulator_architecture(merged_options, sim_control)
  end

  self.log_run_loop_options(merged_options, xctools)

  automation_template = automation_template(xctools)

  log_header("Starting on #{device_target} App: #{bundle_dir_or_bundle_id}")

  pid = instruments.spawn(automation_template, merged_options, log_file)

  File.open(File.join(results_dir, 'run_loop.pid'), 'w') do |f|
    f.write pid
  end

  run_loop = {:pid => pid,
              :index => 1,
              :uia_strategy => uia_strategy,
              :udid => udid,
              :app => bundle_dir_or_bundle_id,
              :repl_path => repl_path,
              :log_file => log_file,
              :results_dir => results_dir}

  uia_timeout = options[:uia_timeout] || (ENV['UIA_TIMEOUT'] && ENV['UIA_TIMEOUT'].to_f) || 10

  before = Time.now
  begin

    if options[:validate_channel]
      options[:validate_channel].call(run_loop, 0, uia_timeout)
    else
      cmd = "UIALogger.logMessage('Listening for run loop commands')"
      File.open(repl_path, 'w') { |file| file.puts "0:#{cmd}" }
      Timeout::timeout(timeout, TimeoutError) do
        read_response(run_loop, 0, uia_timeout)
      end
    end
  rescue TimeoutError => e
    if ENV['DEBUG'] == '1'
      puts "Failed to launch."
      puts "#{e}: #{e && e.message}"
    end
    raise TimeoutError, "Time out waiting for UIAutomation run-loop to Start. \n Logfile #{log_file} \n\n #{File.read(log_file)}\n"
  end

  if ENV['DEBUG']=='1'
    puts "Launching took #{Time.now-before} seconds"
  end

  dylib_path = self.dylib_path_from_options(merged_options)

  if dylib_path
    RunLoop::LLDB.kill_lldb_processes
    app = RunLoop::App.new(options[:app])
    lldb = RunLoop::DylibInjector.new(app.executable_name, dylib_path)
    lldb.retriable_inject_dylib
  end

  run_loop
end

.script_for_key(key) ⇒ Object



72
73
74
75
76
77
# File 'lib/run_loop/core.rb', line 72

def self.script_for_key(key)
  if SCRIPTS[key].nil?
    return nil
  end
  File.join(scripts_path, SCRIPTS[key])
end

.scripts_pathObject



34
35
36
# File 'lib/run_loop/core.rb', line 34

def self.scripts_path
  SCRIPTS_PATH
end

.udid_and_bundle_for_launcher(device_target, options, xctools = RunLoop::XCTools.new) ⇒ Object



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/run_loop/core.rb', line 362

def self.udid_and_bundle_for_launcher(device_target, options, xctools=RunLoop::XCTools.new)
  bundle_dir_or_bundle_id = options[:app] || ENV['BUNDLE_ID']|| ENV['APP_BUNDLE_PATH'] || ENV['APP']

  unless bundle_dir_or_bundle_id
    raise 'key :app or environment variable APP_BUNDLE_PATH, BUNDLE_ID or APP must be specified as path to app bundle (simulator) or bundle id (device)'
  end

  udid = nil

  if xctools.xcode_version_gte_51?
    if device_target.nil? || device_target.empty? || device_target == 'simulator'
      device_target = self.default_simulator(xctools)
    end
    udid = device_target

    unless /simulator/i.match(device_target)
      bundle_dir_or_bundle_id = options[:bundle_id] if options[:bundle_id]
    end
  else
    if device_target == 'simulator'

      unless File.exist?(bundle_dir_or_bundle_id)
        raise "Unable to find app in directory #{bundle_dir_or_bundle_id} when trying to launch simulator"
      end


      device = options[:device] || :iphone
      device = device && device.to_sym

      plistbuddy='/usr/libexec/PlistBuddy'
      plistfile="#{bundle_dir_or_bundle_id}/Info.plist"
      if device == :iphone
        uidevicefamily=1
      else
        uidevicefamily=2
      end
      system("#{plistbuddy} -c 'Delete :UIDeviceFamily' '#{plistfile}'")
      system("#{plistbuddy} -c 'Add :UIDeviceFamily array' '#{plistfile}'")
      system("#{plistbuddy} -c 'Add :UIDeviceFamily:0 integer #{uidevicefamily}' '#{plistfile}'")
    else
      udid = device_target
      bundle_dir_or_bundle_id = options[:bundle_id] if options[:bundle_id]
    end
  end
  return udid, bundle_dir_or_bundle_id
end

.validate_index_written(run_loop, index, logger) ⇒ Object



458
459
460
461
462
463
464
465
466
467
468
469
# File 'lib/run_loop/core.rb', line 458

def self.validate_index_written(run_loop, index, logger)
  begin
    Timeout::timeout(10, TimeoutError) do
      Core.read_response(run_loop, index, 10, 'last_index')
    end
    RunLoop.log_info(logger, "validate index written for index #{index} ok")
    return true
  rescue TimeoutError => _
    RunLoop.log_info(logger, "validate index written for index #{index} failed. Retrying.")
    return false
  end
end

.write_request(run_loop, cmd, logger = nil) ⇒ Object



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
# File 'lib/run_loop/core.rb', line 436

def self.write_request(run_loop, cmd, logger=nil)
  repl_path = run_loop[:repl_path]
  index = run_loop[:index]
  cmd_str = "#{index}:#{escape_host_command(cmd)}"
  should_log = (ENV['DEBUG'] == '1')
  RunLoop.log_info(logger, cmd_str) if should_log
  write_succeeded = false
  2.times do |i|
    RunLoop.log_info(logger, "Trying write of command #{cmd_str} at index #{index}") if should_log
    File.open(repl_path, 'w') { |f| f.puts(cmd_str) }
    write_succeeded = validate_index_written(run_loop, index, logger)
    break if write_succeeded
  end
  unless write_succeeded
    RunLoop.log_info(logger, 'Failing...Raising RunLoop::WriteFailedError') if should_log
    raise RunLoop::WriteFailedError.new("Trying write of command #{cmd_str} at index #{index}")
  end
  run_loop[:index] = index + 1
  RunLoop::HostCache.default.write(run_loop)
  index
end

.xcode_version(xctools = RunLoop::XCTools.new) ⇒ Object

Deprecated.

1.0.0 replaced with Xctools#version



410
411
412
# File 'lib/run_loop/core.rb', line 410

def self.xcode_version(xctools=RunLoop::XCTools.new)
  xctools.xcode_version.to_s
end