Method: RunLoop::Instruments#spawn
- Defined in:
- lib/run_loop/instruments.rb
#spawn(automation_template, options, log_file) ⇒ Integer
TODO:
Do I need to enumerate the launch options in the docs?
TODO:
Should this raise errors?
TODO:
Is this jruby compatible?
Spawn a new instruments process in the context of xcrun and detach.
160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/run_loop/instruments.rb', line 160 def spawn(automation_template, , log_file) env = { "CLOBBER" => "1" } splat_args = spawn_arguments(automation_template, ) logger = [:logger] RunLoop::Logging.log_debug(logger, "xcrun #{splat_args.join(' ')} >& #{log_file}") pid = Process.spawn(env, 'xcrun', *splat_args, {:out => log_file, :err => log_file}) Process.detach(pid) pid.to_i end |